<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh_CN">
<context>
    <name>AmmoSchemeModel</name>
    <message>
        <source>new</source>
        <translation>新</translation>
    </message>
</context>
<context>
    <name>FreqSpinBox</name>
    <message>
        <source>Never</source>
        <translation>从不</translation>
    </message>
    <message numerus="yes">
        <source>Every %1 turn</source>
        <translation>
            <numerusform>每 %1 个回合</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>GameCFGWidget</name>
    <message>
        <source>Error</source>
        <translation>错误</translation>
    </message>
    <message>
        <source>Illegal ammo scheme</source>
        <translation>无法使用此弹药设置</translation>
    </message>
    <message>
        <source>Edit schemes</source>
        <translation type="unfinished">修改游戏设置</translation>
    </message>
    <message>
        <source>Edit weapons</source>
        <translation type="unfinished">修改武器设置</translation>
    </message>
</context>
<context>
    <name>HWChatWidget</name>
    <message>
        <source>%1 *** %2 has been removed from your ignore list</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 *** %2 has been added to your ignore list</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 *** %2 has been removed from your friends list</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 *** %2 has been added to your friends list</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HWForm</name>
    <message>
        <source>Error</source>
        <translation>错误</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>确认</translation>
    </message>
    <message>
        <source>Cannot save record to file %1</source>
        <translation>无法录入文件 %1</translation>
    </message>
    <message>
        <source>Unable to start the server</source>
        <translation>开启服务端出现错误</translation>
    </message>
    <message>
        <source>new</source>
        <translation>新</translation>
    </message>
    <message>
        <source>Please select record from the list above</source>
        <translation>请选择一个记录</translation>
    </message>
</context>
<context>
    <name>HWGame</name>
    <message>
        <source>en.txt</source>
        <translation>zh_CN.txt</translation>
    </message>
    <message>
        <source>Cannot open demofile %1</source>
        <translation>DEMO %1 打不开</translation>
    </message>
</context>
<context>
    <name>HWMapContainer</name>
    <message>
        <source>Map</source>
        <translation>地图</translation>
    </message>
    <message>
        <source>Themes</source>
        <translation>主题</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>过滤</translation>
    </message>
    <message>
        <source>All</source>
        <translation>全部</translation>
    </message>
    <message>
        <source>Small</source>
        <translation>小型</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>中型</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>大型</translation>
    </message>
    <message>
        <source>Cavern</source>
        <translation>洞穴</translation>
    </message>
    <message>
        <source>Wacky</source>
        <translation>曲折</translation>
    </message>
    <message>
        <source>Type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Small tunnels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Medium tunnels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Large tunnels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Small floating islands</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Medium floating islands</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Large floating islands</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HWNetServersModel</name>
    <message>
        <source>Title</source>
        <translation>标题</translation>
    </message>
    <message>
        <source>IP</source>
        <translation>IP</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>端口</translation>
    </message>
</context>
<context>
    <name>HWNewNet</name>
    <message>
        <source>The host was not found. Please check the host name and port settings.</source>
        <translation>错误没找到这个主机。请检查主机名和端口设置。</translation>
    </message>
    <message>
        <source>Connection refused</source>
        <translation>连接被拒绝</translation>
    </message>
    <message>
        <source>Quit reason: </source>
        <translation>退出原因：</translation>
    </message>
    <message>
        <source>Room destroyed</source>
        <translation>房间损坏</translation>
    </message>
    <message>
        <source>You got kicked</source>
        <translation>被踢出</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>密码</translation>
    </message>
    <message>
        <source>Your nickname %1 is
registered on Hedgewars.org
Please provide your password
or pick another nickname:</source>
        <translation>您的昵称%1
在Hedgewars.org已注册
请输入您的密码
或选择另一个昵称:</translation>
    </message>
    <message>
        <source>%1 *** %2 has joined the room</source>
        <translation>%1 *** %2已经进入房间</translation>
    </message>
    <message>
        <source>%1 *** %2 has joined</source>
        <translation>%1 *** %2已经进入</translation>
    </message>
    <message>
        <source>%1 *** %2 has left (%3)</source>
        <translation>%1 *** %2已经离开(%3)</translation>
    </message>
    <message>
        <source>%1 *** %2 has left</source>
        <translation>%1 *** %2已经离开</translation>
    </message>
</context>
<context>
    <name>KB</name>
    <message>
        <source>SDL_ttf returned error while rendering text, most propably it is related to the bug in freetype2. It&apos;s recommended to update your freetype lib.</source>
        <translation>SDL_ttf 返回错误-渲染文字失败，可能有关freetype2的bug。建议升级 freetype。</translation>
    </message>
</context>
<context>
    <name>PageAdmin</name>
    <message>
        <source>Server message:</source>
        <translation type="obsolete">服务器信息：</translation>
    </message>
    <message>
        <source>Set message</source>
        <translation type="obsolete">设定信息</translation>
    </message>
    <message>
        <source>Clear Accounts Cache</source>
        <translation>清空账户缓存</translation>
    </message>
    <message>
        <source>Fetch data</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Server message for latest version:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Server message for previous versions:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Latest version protocol number:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MOTD preview:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set data</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PageConnecting</name>
    <message>
        <source>Connecting...</source>
        <translation>连接中...</translation>
    </message>
</context>
<context>
    <name>PageEditTeam</name>
    <message>
        <source>General</source>
        <translation>常规</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation>进阶</translation>
    </message>
</context>
<context>
    <name>PageGameStats</name>
    <message>
        <source>&lt;p&gt;The best shot award was won by &lt;b&gt;%1&lt;/b&gt; with &lt;b&gt;%2&lt;/b&gt; pts.&lt;/p&gt;</source>
        <translation type="unfinished">&lt;p&gt;最佳射手是 &lt;b&gt;%1&lt;/b&gt;。伤害 &lt;b&gt;%2&lt;/b&gt;点。&lt;/p&gt;</translation>
    </message>
    <message numerus="yes">
        <source>&lt;p&gt;The best killer is &lt;b&gt;%1&lt;/b&gt; with &lt;b&gt;%2&lt;/b&gt; kills in a turn.&lt;/p&gt;</source>
        <translation type="unfinished">
            <numerusform>&lt;p&gt;最佳杀手是 &lt;b&gt;%1&lt;/b&gt;单回合击杀刺猬数:&lt;b&gt;%2&lt;/b&gt;&lt;/p&gt;</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>&lt;p&gt;A total of &lt;b&gt;%1&lt;/b&gt; hedgehog(s) were killed during this round.&lt;/p&gt;</source>
        <translation type="unfinished">
            <numerusform>&lt;p&gt;本轮总共有&lt;b&gt;%1&lt;/b&gt;只刺猬被击杀&lt;/p&gt;</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>PageMain</name>
    <message>
        <source>Local Game (Play a game on a single computer)</source>
        <translation>本地游戏（在一台电脑上）</translation>
    </message>
    <message>
        <source>Network Game (Play a game across a network)</source>
        <translation>网络游戏（通过网络）</translation>
    </message>
</context>
<context>
    <name>PageMultiplayer</name>
    <message>
        <source>Start</source>
        <translation>开始</translation>
    </message>
</context>
<context>
    <name>PageNet</name>
    <message>
        <source>Error</source>
        <translation>错误</translation>
    </message>
    <message>
        <source>Please select server from the list above</source>
        <translation>请选择一个服务器</translation>
    </message>
</context>
<context>
    <name>PageNetGame</name>
    <message>
        <source>Control</source>
        <translation>房间管理</translation>
    </message>
</context>
<context>
    <name>PageNetType</name>
    <message>
        <source>LAN game</source>
        <translation>局域网游戏</translation>
    </message>
    <message>
        <source>Official server</source>
        <translation>官方服务器</translation>
    </message>
</context>
<context>
    <name>PageOptions</name>
    <message>
        <source>New team</source>
        <translation>新队伍</translation>
    </message>
    <message>
        <source>Edit team</source>
        <translation>修改队伍设定</translation>
    </message>
    <message>
        <source>Delete team</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New weapon scheme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit weapon scheme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete weapon scheme</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PagePlayDemo</name>
    <message>
        <source>Error</source>
        <translation>错误</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>确认</translation>
    </message>
    <message>
        <source>Rename dialog</source>
        <translation>重命名对话框</translation>
    </message>
    <message>
        <source>Enter new file name:</source>
        <translation>输入新的文件名:</translation>
    </message>
    <message>
        <source>Cannot rename to</source>
        <translation>不能改变名字</translation>
    </message>
    <message>
        <source>Cannot delete file</source>
        <translation>不能删除文件</translation>
    </message>
    <message>
        <source>Please select record from the list</source>
        <translation>请从列表选择记录</translation>
    </message>
</context>
<context>
    <name>PageRoomsList</name>
    <message>
        <source>Create</source>
        <translation>建立</translation>
    </message>
    <message>
        <source>Join</source>
        <translation>加入</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>刷新</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>错误</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>确认</translation>
    </message>
    <message>
        <source>Admin features</source>
        <translation>管理员功能</translation>
    </message>
    <message>
        <source>Room Name:</source>
        <translation type="unfinished">房间名:</translation>
    </message>
    <message>
        <source>This game is in lobby.
You may join and start playing once the game starts.</source>
        <translation type="unfinished">游戏正在等待中。
您可以加入等待游戏开始。</translation>
    </message>
    <message>
        <source>This game is in progress.
You may join and spectate now but you&apos;ll have to wait for the game to end to start playing.</source>
        <translation type="unfinished">游戏正在进行中。
您可以加入观战但必须等游戏结束才能参与游戏。</translation>
    </message>
    <message>
        <source>%1 is the host. He may adjust settings and start the game.</source>
        <translation type="unfinished">%1 是房主，他可以调整设置、开始游戏。</translation>
    </message>
    <message>
        <source>Random Map</source>
        <translation type="unfinished">随机地图</translation>
    </message>
    <message>
        <source>Games may be played on precreated or randomized maps.</source>
        <translation>游戏可以在预先创建或者随机产生的地图上进行。</translation>
    </message>
    <message>
        <source>The Game Scheme defines general options and preferences like Round Time, Sudden Death or Vampirism.</source>
        <translation type="unfinished">游戏设置包括一般选项例如回合时间，突然死亡或吸血模式。</translation>
    </message>
    <message>
        <source>The Weapon Scheme defines available weapons and their ammunition count.</source>
        <translation type="unfinished">武器设置包括可以选用的武器和弹药数量。</translation>
    </message>
    <message numerus="yes">
        <source>There are %1 clients connected to this room.</source>
        <translation type="unfinished">
            <numerusform>有 %1 个客户端连接到这个房间。</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>There are %1 teams participating in this room.</source>
        <translation type="unfinished">
            <numerusform>有 %1 个队伍加入这个房间。</numerusform>
        </translation>
    </message>
    <message>
        <source>Please enter room name</source>
        <translation>请键入房间名</translation>
    </message>
    <message>
        <source>Please select room from the list</source>
        <translation>请从列表选中房间</translation>
    </message>
    <message>
        <source>Random Maze</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PageScheme</name>
    <message>
        <source>New</source>
        <translation>新模式</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>删除</translation>
    </message>
    <message>
        <source>Defend your fort and destroy the opponents, two team colours max!</source>
        <translation>保卫你的城堡，破坏对手的，努力吧！</translation>
    </message>
    <message>
        <source>Teams will start on opposite sides of the terrain, two team colours max!</source>
        <translation>队伍开始在对手的地盘，努力！</translation>
    </message>
    <message>
        <source>Land can not be destroyed!</source>
        <translation>地面无法破坏！</translation>
    </message>
    <message>
        <source>Add an indestructable border around the terrain</source>
        <translation>添加不可毁坏地边界</translation>
    </message>
    <message>
        <source>Lower gravity</source>
        <translation>低重力</translation>
    </message>
    <message>
        <source>Assisted aiming with laser sight</source>
        <translation>激光瞄准辅助</translation>
    </message>
    <message>
        <source>All hogs have a personal forcefield</source>
        <translation>每个刺猬都有一个力场</translation>
    </message>
    <message>
        <source>Enable random mines</source>
        <translation>开启随机地雷</translation>
    </message>
    <message>
        <source>Gain 80% of the damage you do back in health</source>
        <translation>伤害的80%变成自身力量</translation>
    </message>
    <message>
        <source>Share your opponents pain, share their damage</source>
        <translation>分担你的对手的疼痛</translation>
    </message>
    <message>
        <source>Your hogs are unable to move, put your artillery skills to the test</source>
        <translation>你的刺猬不能移动，检验你射击技巧的时候到了</translation>
    </message>
    <message>
        <source>Random</source>
        <translation>随机</translation>
    </message>
    <message>
        <source>Seconds</source>
        <translation>秒钟</translation>
    </message>
    <message>
        <source>Order of play is random instead of in room order.</source>
        <translation>随机出场顺序</translation>
    </message>
    <message>
        <source>Play with a King. If he dies, your side dies.</source>
        <translation>国王不能死!!</translation>
    </message>
    <message>
        <source>Take turns placing your hedgehogs before the start of play.</source>
        <translation>在开局前手动放置刺猬</translation>
    </message>
    <message>
        <source>Ammo is shared between all teams that share a colour.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disable girders when generating random maps.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disable land objects when generating random maps.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PageSelectWeapon</name>
    <message>
        <source>Default</source>
        <translation>默认</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>删除</translation>
    </message>
</context>
<context>
    <name>PageSinglePlayer</name>
    <message>
        <source>Simple Game (a quick game against the computer, settings are chosen for you)</source>
        <translation>快速游戏 (对抗电脑，固定设置)</translation>
    </message>
    <message>
        <source>Multiplayer (play a hotseat game against your friends, or AI teams)</source>
        <translation>多人游戏 (热坐对抗朋友或AI)</translation>
    </message>
    <message>
        <source>Training Mode (Practice your skills in a range of training missions). IN DEVELOPMENT</source>
        <translation>训练模式 (一系列训练任务)。开发中</translation>
    </message>
    <message>
        <source>Demos (Watch recorded demos)</source>
        <translation>Demo (观看记录的Demo)</translation>
    </message>
    <message>
        <source>Load (Load a previously saved game)</source>
        <translation>读取 (读取之前保存的游戏)</translation>
    </message>
</context>
<context>
    <name>QAction</name>
    <message>
        <source>Kick</source>
        <translation>踢</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>开始</translation>
    </message>
    <message>
        <source>Restrict Joins</source>
        <translation>限制参与</translation>
    </message>
    <message>
        <source>Restrict Team Additions</source>
        <translation>限制团队插件</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>信息</translation>
    </message>
    <message>
        <source>Ban</source>
        <translation>屏蔽</translation>
    </message>
    <message>
        <source>Follow</source>
        <translation>跟随</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add friend</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unignore</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove friend</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QCheckBox</name>
    <message>
        <source>Check for updates at startup</source>
        <translation>启动时检查程序升级</translation>
    </message>
    <message>
        <source>Enable sound</source>
        <translation type="unfinished">开启游戏音效</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>游戏全屏幕</translation>
    </message>
    <message>
        <source>Show FPS</source>
        <translation>显示帧率 (FPS)</translation>
    </message>
    <message>
        <source>Alternative damage show</source>
        <translation>另一种伤害显示方式</translation>
    </message>
    <message>
        <source>Enable music</source>
        <translation type="unfinished">开启游戏音乐</translation>
    </message>
    <message>
        <source>Frontend fullscreen</source>
        <translation>界面全屏幕</translation>
    </message>
    <message>
        <source>Append date and time to record file name</source>
        <translation>记录名称中包含具体时间日期</translation>
    </message>
    <message>
        <source>Reduced quality</source>
        <translation type="unfinished">降低显示效果</translation>
    </message>
    <message>
        <source>Show ammo menu tooltips</source>
        <translation type="unfinished">显示武器提示信息</translation>
    </message>
    <message>
        <source>Enable frontend sounds</source>
        <translation type="unfinished">开启菜单音效</translation>
    </message>
    <message>
        <source>Enable frontend music</source>
        <translation type="unfinished">开启菜单音乐</translation>
    </message>
    <message>
        <source>Frontend effects</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QComboBox</name>
    <message>
        <source>generated map...</source>
        <translation>生成地图...</translation>
    </message>
    <message>
        <source>Human</source>
        <translation>玩家</translation>
    </message>
    <message>
        <source>Level</source>
        <translation>Lv 级别</translation>
    </message>
    <message>
        <source>(System default)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>generated maze...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mission</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QGroupBox</name>
    <message>
        <source>Team Members</source>
        <translation>成员</translation>
    </message>
    <message>
        <source>Fort</source>
        <translation>城堡模式</translation>
    </message>
    <message>
        <source>Key binds</source>
        <translation>键位绑定</translation>
    </message>
    <message>
        <source>Teams</source>
        <translation>队伍</translation>
    </message>
    <message>
        <source>Audio/Graphic options</source>
        <translation>音频/视频选项</translation>
    </message>
    <message>
        <source>Playing teams</source>
        <translation>玩家队伍</translation>
    </message>
    <message>
        <source>Net game</source>
        <translation>网络游戏</translation>
    </message>
    <message>
        <source>Weapons</source>
        <translation>武器</translation>
    </message>
    <message>
        <source>Game Modifiers</source>
        <translation>游戏修改</translation>
    </message>
    <message>
        <source>Basic Settings</source>
        <translation>基本设置</translation>
    </message>
    <message>
        <source>Team Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Misc</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QLabel</name>
    <message>
        <source>Net nick</source>
        <translation>网络游戏昵称</translation>
    </message>
    <message>
        <source>This program is distributed under the GNU General Public License</source>
        <translation>This program is distributed under the GNU General Public License</translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation>分辨率</translation>
    </message>
    <message>
        <source>FPS limit</source>
        <translation>FPS 上限</translation>
    </message>
    <message>
        <source>Developers:</source>
        <translation>开发者:</translation>
    </message>
    <message>
        <source>Art:</source>
        <translation>艺术:</translation>
    </message>
    <message>
        <source>Translations:</source>
        <translation>翻译:</translation>
    </message>
    <message>
        <source>Special thanks:</source>
        <translation>特别感谢:</translation>
    </message>
    <message>
        <source>Server name:</source>
        <translation>服务器名:</translation>
    </message>
    <message>
        <source>Server port:</source>
        <translation>服务器端口:</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation>主机:</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>端口:</translation>
    </message>
    <message>
        <source>Weapons</source>
        <translation>武器</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>版本</translation>
    </message>
    <message>
        <source>Sounds:</source>
        <translation>声音:</translation>
    </message>
    <message>
        <source>Initial sound volume</source>
        <translation>初始音量</translation>
    </message>
    <message>
        <source>Damage Modifier</source>
        <translation>伤害修改</translation>
    </message>
    <message>
        <source>Turn Time</source>
        <translation>回合时间</translation>
    </message>
    <message>
        <source>Initial Health</source>
        <translation>初始生命值</translation>
    </message>
    <message>
        <source>Sudden Death Timeout</source>
        <translation>死亡模式倒计时</translation>
    </message>
    <message>
        <source>Scheme Name:</source>
        <translation>设置名称：</translation>
    </message>
    <message>
        <source>Crate Drops</source>
        <translation>箱子降落</translation>
    </message>
    <message>
        <source>Game scheme</source>
        <translation>游戏设置</translation>
    </message>
    <message>
        <source>Mines Time</source>
        <translation>布雷时间</translation>
    </message>
    <message>
        <source>Mines</source>
        <translation>地雷</translation>
    </message>
    <message>
        <source>% Dud Mines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Grave</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Flag</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Voice</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Locale</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Restart game to apply</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This SVN build is &apos;work in progress&apos; and may not be compatible with other versions of the game.
Some features might be broken or incomplete. Use at your own risk!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Explosives</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QLineEdit</name>
    <message>
        <source>unnamed</source>
        <translation>无名</translation>
    </message>
</context>
<context>
    <name>QMainWindow</name>
    <message>
        <source>Hedgewars %1</source>
        <translation>刺猬大作战 %1</translation>
    </message>
</context>
<context>
    <name>QMessageBox</name>
    <message>
        <source>Error</source>
        <translation>错误</translation>
    </message>
    <message>
        <source>Failed to open data directory:
%1
Please check your installation</source>
        <translation>打不开数据文件目录:
%1
请检查</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>网络</translation>
    </message>
    <message>
        <source>Connection to server is lost</source>
        <translation>服务器连接丢失</translation>
    </message>
    <message>
        <source>Weapons</source>
        <translation>武器</translation>
    </message>
    <message>
        <source>Can not delete default weapon set</source>
        <translation>不能删除默认武器设定</translation>
    </message>
    <message>
        <source>Really delete this weapon set?</source>
        <translation>真的删除这个武器设定吗?</translation>
    </message>
    <message>
        <source>Can not edit default weapon set</source>
        <translation>不能更改默认的武器设定</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Error</source>
        <translation>错误</translation>
    </message>
    <message>
        <source>Cannot create directory %1</source>
        <translation>无法创建路径 %1</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>确认</translation>
    </message>
    <message>
        <source>Nickname</source>
        <translation type="unfinished">昵称</translation>
    </message>
    <message>
        <source>Please enter your nickname</source>
        <translation type="unfinished">请输入您的昵称</translation>
    </message>
</context>
<context>
    <name>QPushButton</name>
    <message>
        <source>Setup</source>
        <translation>设置</translation>
    </message>
    <message>
        <source>Play demo</source>
        <translation>播放 demo</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation>连接</translation>
    </message>
    <message>
        <source>Go!</source>
        <translation>上场！</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>开始</translation>
    </message>
    <message>
        <source>Start server</source>
        <translation>开始服务端</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>更新</translation>
    </message>
    <message>
        <source>Load</source>
        <translation>读取</translation>
    </message>
    <message>
        <source>Specify</source>
        <translation>指定</translation>
    </message>
    <message>
        <source>default</source>
        <translation>默认</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>重命名</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>确定</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>删除</translation>
    </message>
    <message>
        <source>Ready</source>
        <translation>准备好了</translation>
    </message>
    <message>
        <source>Random Team</source>
        <translation type="unfinished">随机队伍分配</translation>
    </message>
</context>
<context>
    <name>QTableWidget</name>
    <message>
        <source>Room Name</source>
        <translation type="unfinished">房间名</translation>
    </message>
    <message>
        <source>C</source>
        <translation type="unfinished">人数</translation>
    </message>
    <message>
        <source>T</source>
        <translation type="unfinished">队伍</translation>
    </message>
    <message>
        <source>Owner</source>
        <translation type="unfinished">创建者</translation>
    </message>
    <message>
        <source>Map</source>
        <translation type="unfinished">地图</translation>
    </message>
    <message>
        <source>Rules</source>
        <translation type="unfinished">规则</translation>
    </message>
    <message>
        <source>Weapons</source>
        <translation type="unfinished">武器</translation>
    </message>
</context>
<context>
    <name>SelWeaponWidget</name>
    <message>
        <source>Weapon set</source>
        <translation type="unfinished">武器设置</translation>
    </message>
    <message>
        <source>Probabilities</source>
        <translation type="unfinished">几率</translation>
    </message>
    <message>
        <source>Ammo in boxes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delays</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TCPBase</name>
    <message>
        <source>Error</source>
        <translation>错误</translation>
    </message>
    <message>
        <source>Unable to start the server: %1.</source>
        <translation>无法开始服务端: %1.</translation>
    </message>
    <message>
        <source>Unable to run engine: %1 (</source>
        <translation>无法运行引擎: %1 (</translation>
    </message>
</context>
<context>
    <name>ToggleButtonWidget</name>
    <message>
        <source>Fort Mode</source>
        <translation>城堡模式</translation>
    </message>
    <message>
        <source>Divide Teams</source>
        <translation>团体行动</translation>
    </message>
    <message>
        <source>Solid Land</source>
        <translation>固实地面</translation>
    </message>
    <message>
        <source>Add Border</source>
        <translation>添加边界</translation>
    </message>
    <message>
        <source>Low Gravity</source>
        <translation>低重力</translation>
    </message>
    <message>
        <source>Laser Sight</source>
        <translation>激光瞄准</translation>
    </message>
    <message>
        <source>Invulnerable</source>
        <translation>刀枪不入</translation>
    </message>
    <message>
        <source>Add Mines</source>
        <translation>布置地雷</translation>
    </message>
    <message>
        <source>Vampirism</source>
        <translation>吸血鬼</translation>
    </message>
    <message>
        <source>Karma</source>
        <translation>因果报应</translation>
    </message>
    <message>
        <source>Artillery</source>
        <translation>射术</translation>
    </message>
    <message>
        <source>Random Order</source>
        <translation type="unfinished">随机顺序</translation>
    </message>
    <message>
        <source>King</source>
        <translation type="unfinished">国王模式</translation>
    </message>
    <message>
        <source>Place Hedgehogs</source>
        <translation type="unfinished">手动放置</translation>
    </message>
    <message>
        <source>Clan Shares Ammo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disable Girders</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disable Land Objects</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>binds</name>
    <message>
        <source>up</source>
        <translation>上</translation>
    </message>
    <message>
        <source>left</source>
        <translation>左</translation>
    </message>
    <message>
        <source>right</source>
        <translation>右</translation>
    </message>
    <message>
        <source>down</source>
        <translation>下</translation>
    </message>
    <message>
        <source>attack</source>
        <translation>攻击</translation>
    </message>
    <message>
        <source>put</source>
        <translation>放</translation>
    </message>
    <message>
        <source>switch</source>
        <translation>切换</translation>
    </message>
    <message>
        <source>slot 1</source>
        <translation>slot 1</translation>
    </message>
    <message>
        <source>slot 2</source>
        <translation>slot 2</translation>
    </message>
    <message>
        <source>slot 3</source>
        <translation>slot 3</translation>
    </message>
    <message>
        <source>slot 4</source>
        <translation>slot 4</translation>
    </message>
    <message>
        <source>slot 5</source>
        <translation>slot 5</translation>
    </message>
    <message>
        <source>slot 6</source>
        <translation>slot 6</translation>
    </message>
    <message>
        <source>slot 7</source>
        <translation>slot 7</translation>
    </message>
    <message>
        <source>slot 8</source>
        <translation>slot 8</translation>
    </message>
    <message>
        <source>timer 1 sec</source>
        <translation>定时1秒</translation>
    </message>
    <message>
        <source>timer 2 sec</source>
        <translation>定时2秒</translation>
    </message>
    <message>
        <source>timer 3 sec</source>
        <translation>定时3秒</translation>
    </message>
    <message>
        <source>timer 4 sec</source>
        <translation>定时4秒</translation>
    </message>
    <message>
        <source>timer 5 sec</source>
        <translation>定时5秒</translation>
    </message>
    <message>
        <source>capture</source>
        <translation>夺取</translation>
    </message>
    <message>
        <source>quit</source>
        <translation>退出</translation>
    </message>
    <message>
        <source>find hedgehog</source>
        <translation>寻找刺猬</translation>
    </message>
    <message>
        <source>ammo menu</source>
        <translation>弹药菜单</translation>
    </message>
    <message>
        <source>volume down</source>
        <translation>降低音量</translation>
    </message>
    <message>
        <source>volume up</source>
        <translation>提高音量</translation>
    </message>
    <message>
        <source>change mode</source>
        <translation>改变模式</translation>
    </message>
    <message>
        <source>pause</source>
        <translation>暂停</translation>
    </message>
    <message>
        <source>slot 9</source>
        <translation>slot 9</translation>
    </message>
    <message>
        <source>hedgehogs
info</source>
        <translation>刺猬大作战
信息</translation>
    </message>
    <message>
        <source>chat</source>
        <translation>聊天</translation>
    </message>
    <message>
        <source>chat history</source>
        <translation>聊天记录</translation>
    </message>
    <message>
        <source>confirmation</source>
        <translation>确认</translation>
    </message>
    <message>
        <source>precise aim</source>
        <translation>练习瞄准</translation>
    </message>
    <message>
        <source>zoom in</source>
        <translation type="unfinished">放大</translation>
    </message>
    <message>
        <source>zoom out</source>
        <translation type="unfinished">缩小</translation>
    </message>
    <message>
        <source>reset zoom</source>
        <translation type="unfinished">重置</translation>
    </message>
    <message>
        <source>long jump</source>
        <translation type="unfinished">跳远</translation>
    </message>
    <message>
        <source>high jump</source>
        <translation type="unfinished">跳高</translation>
    </message>
</context>
<context>
    <name>binds (categories)</name>
    <message>
        <source>Basic controls</source>
        <translation type="unfinished">基本控制</translation>
    </message>
    <message>
        <source>Weapon controls</source>
        <translation type="unfinished">武器控制</translation>
    </message>
    <message>
        <source>Camera and cursor controls</source>
        <translation type="unfinished">镜头和光标控制</translation>
    </message>
    <message>
        <source>Other</source>
        <translation type="unfinished">其他</translation>
    </message>
</context>
<context>
    <name>binds (descriptions)</name>
    <message>
        <source>Move your hogs and aim:</source>
        <translation type="unfinished">移动、瞄准：</translation>
    </message>
    <message>
        <source>Traverse gaps and obstacles by jumping:</source>
        <translation type="unfinished">越过障碍：</translation>
    </message>
    <message>
        <source>Fire your selected weapon or trigger an utility item:</source>
        <translation type="unfinished">开火、使用物品：</translation>
    </message>
    <message>
        <source>Pick a weapon or a target location under the cursor:</source>
        <translation type="unfinished">选取武器、目的地：</translation>
    </message>
    <message>
        <source>Switch your currently active hog (if possible):</source>
        <translation type="unfinished">切换刺猬（如果可用）：</translation>
    </message>
    <message>
        <source>Pick a weapon or utility item:</source>
        <translation type="unfinished">选取武器、物品：</translation>
    </message>
    <message>
        <source>Set the timer on bombs and timed weapons:</source>
        <translation type="unfinished">设置定时炸弹等武器时间：</translation>
    </message>
    <message>
        <source>Move the camera to the active hog:</source>
        <translation type="unfinished">移动镜头到选中刺猬：</translation>
    </message>
    <message>
        <source>Move the cursor or camera without using the mouse:</source>
        <translation type="unfinished">不用鼠标移动光标或镜头：</translation>
    </message>
    <message>
        <source>Modify the camera&apos;s zoom level:</source>
        <translation type="unfinished">调整镜头放大倍数：</translation>
    </message>
    <message>
        <source>Talk to your team or all participants:</source>
        <translation type="unfinished">同队友或全部参与者对话：</translation>
    </message>
    <message>
        <source>Pause, continue or leave your game:</source>
        <translation type="unfinished">暂停、继续或离开游戏：</translation>
    </message>
    <message>
        <source>Modify the game&apos;s volume while playing:</source>
        <translation type="unfinished">调整游戏时音量：</translation>
    </message>
    <message>
        <source>Toggle fullscreen mode:</source>
        <translation type="unfinished">全屏模式：</translation>
    </message>
    <message>
        <source>Take a screenshot:</source>
        <translation type="unfinished">截图：</translation>
    </message>
    <message>
        <source>Toggle labels above hedgehogs:</source>
        <translation type="unfinished">切换刺猬标签显示方式：</translation>
    </message>
</context>
<context>
    <name>binds (keys)</name>
    <message>
        <source>Axis</source>
        <translation type="unfinished">轴</translation>
    </message>
    <message>
        <source>(Up)</source>
        <translation type="unfinished">上</translation>
    </message>
    <message>
        <source>(Down)</source>
        <translation type="unfinished">下</translation>
    </message>
    <message>
        <source>Hat</source>
        <translation type="unfinished">帽子</translation>
    </message>
    <message>
        <source>(Left)</source>
        <translation type="unfinished">左</translation>
    </message>
    <message>
        <source>(Right)</source>
        <translation type="unfinished">右</translation>
    </message>
    <message>
        <source>Button</source>
        <translation type="unfinished">按键</translation>
    </message>
    <message>
        <source>Keyboard</source>
        <translation type="unfinished">键盘</translation>
    </message>
    <message>
        <source>Mouse: Left button</source>
        <translation>鼠标：左键</translation>
    </message>
    <message>
        <source>Mouse: Middle button</source>
        <translation>鼠标：中键</translation>
    </message>
    <message>
        <source>Mouse: Right button</source>
        <translation>鼠标：右键</translation>
    </message>
    <message>
        <source>Mouse: Wheel up</source>
        <translation>鼠标滚轮：向上</translation>
    </message>
    <message>
        <source>Mouse: Wheel down</source>
        <translation>鼠标滚轮：向下</translation>
    </message>
    <message>
        <source>Backspace</source>
        <translation>退格键</translation>
    </message>
    <message>
        <source>Tab</source>
        <translation>制表键</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>清除</translation>
    </message>
    <message>
        <source>Return</source>
        <translation>返回</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>暂停键</translation>
    </message>
    <message>
        <source>Escape</source>
        <translation>退出键</translation>
    </message>
    <message>
        <source>Space</source>
        <translation>空格键</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>删除键</translation>
    </message>
    <message>
        <source>Numpad 0</source>
        <translation>小键盘0</translation>
    </message>
    <message>
        <source>Numpad 1</source>
        <translation>小键盘1</translation>
    </message>
    <message>
        <source>Numpad 2</source>
        <translation>小键盘2</translation>
    </message>
    <message>
        <source>Numpad 3</source>
        <translation>小键盘3</translation>
    </message>
    <message>
        <source>Numpad 4</source>
        <translation>小键盘4</translation>
    </message>
    <message>
        <source>Numpad 5</source>
        <translation>小键盘5</translation>
    </message>
    <message>
        <source>Numpad 6</source>
        <translation>小键盘6</translation>
    </message>
    <message>
        <source>Numpad 7</source>
        <translation>小键盘7</translation>
    </message>
    <message>
        <source>Numpad 8</source>
        <translation>小键盘8</translation>
    </message>
    <message>
        <source>Numpad 9</source>
        <translation>小键盘9</translation>
    </message>
    <message>
        <source>Numpad .</source>
        <translation>小键盘.</translation>
    </message>
    <message>
        <source>Numpad /</source>
        <translation>小键盘/</translation>
    </message>
    <message>
        <source>Numpad *</source>
        <translation>小键盘*</translation>
    </message>
    <message>
        <source>Numpad -</source>
        <translation>小键盘-</translation>
    </message>
    <message>
        <source>Numpad +</source>
        <translation>小键盘+</translation>
    </message>
    <message>
        <source>Enter</source>
        <translation>回车键</translation>
    </message>
    <message>
        <source>Equals</source>
        <translation>等于</translation>
    </message>
    <message>
        <source>Up</source>
        <translation>上</translation>
    </message>
    <message>
        <source>Down</source>
        <translation>下</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>右</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>左</translation>
    </message>
    <message>
        <source>Insert</source>
        <translation>插入键</translation>
    </message>
    <message>
        <source>Home</source>
        <translation>Home键</translation>
    </message>
    <message>
        <source>End</source>
        <translation>End键</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>向上翻页键</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>向下翻页键</translation>
    </message>
    <message>
        <source>Num lock</source>
        <translation>小键盘数字锁</translation>
    </message>
    <message>
        <source>Caps lock</source>
        <translation>大小写切换键</translation>
    </message>
    <message>
        <source>Scroll lock</source>
        <translation>Scroll Lock键</translation>
    </message>
    <message>
        <source>Right shift</source>
        <translation>右Shift键</translation>
    </message>
    <message>
        <source>Left shift</source>
        <translation>左Shift键</translation>
    </message>
    <message>
        <source>Right ctrl</source>
        <translation>右Ctrl键</translation>
    </message>
    <message>
        <source>Left ctrl</source>
        <translation>左Ctrl键</translation>
    </message>
    <message>
        <source>Right alt</source>
        <translation>右Alt键</translation>
    </message>
    <message>
        <source>Left alt</source>
        <translation>左Alt键</translation>
    </message>
    <message>
        <source>Right meta</source>
        <translation>右meta键</translation>
    </message>
    <message>
        <source>Left meta</source>
        <translation>左meta键</translation>
    </message>
    <message>
        <source>A button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>B button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>X button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Y button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>LB button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RB button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Back button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Left stick</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Right stick</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Left stick (Right)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Left stick (Left)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Left stick (Down)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Left stick (Up)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Left trigger</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Right trigger</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Right stick (Down)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Right stick (Up)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Right stick (Right)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Right stick (Left)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DPad</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
